@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-VERSION = (3, 1, 2)
+VERSION = (3, 1, 3)
 
 
 def get_version(version):
@@ -19,4 +19,11 @@ def get_version(version):
 
 __version__ = get_version(VERSION)
 
-default_app_config = 'django_extensions.apps.DjangoExtensionsConfig'
+try:
+    import django
+
+    if django.VERSION < (3, 2):
+        default_app_config = 'django_extensions.apps.DjangoExtensionsConfig'
+except ModuleNotFoundError:
+    # this part is useful for allow setup.py to be used for version checks
+    pass
