@@ -204,7 +204,7 @@ class Command(BaseCommand):
 
         return {'django_extensions': ks}
 
-    def run_notebookapp(self, app_init, options, use_kernel_specs=True):
+    def run_notebookapp(self, app_init, options, use_kernel_specs=True, history=True):
         no_browser = options['no_browser']
 
         if self.extra_args:
@@ -235,6 +235,10 @@ class Command(BaseCommand):
         if not use_kernel_specs:
             notebook_arguments.extend(ipython_arguments)
 
+        # disable history if not already configured in some other way
+        if not history and not any(arg.startswith('--HistoryManager') for arg in ipython_arguments):
+            ipython_arguments.append('--HistoryManager.enabled=False')
+
         if not callable(app_init):
             app = app_init
             warnings.warn('Initialize should be a callable not an app instance', DeprecationWarning)
@@ -322,7 +326,7 @@ class Command(BaseCommand):
                 return app
 
         def run_jupyterlab():
-            self.run_notebookapp(app_init, options)
+            self.run_notebookapp(app_init, options, history=False)
         return run_jupyterlab
 
     @shell_runner(flags=['--plain'], name='plain Python')
@@ -571,7 +575,7 @@ for k, m in shells.import_objects({}, no_style()).items():
 
             if options['command']:
                 imported_objects = self.get_imported_objects(options)
-                exec(options['command'], {}, imported_objects)
+                exec(options['command'], imported_objects)
                 return None
 
             runner()
